@@ -1,6 +1,6 @@
 package Test::Map::Tube;
 
-$Test::Map::Tube::VERSION   = '0.57';
+$Test::Map::Tube::VERSION   = '0.58';
 $Test::Map::Tube::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Test::Map::Tube - Interface to test Map::Tube features.
 
 =head1 VERSION
 
-Version 0.57
+Version 0.58
 
 =cut
 
@@ -26,8 +26,8 @@ my $PLAN      = 0;
 
 =head1 DESCRIPTION
 
-It's main responsibilty  is  to validate the map data as used by the package that
-takes the role of L<Map::Tube>.You can also unit test map functions as well.
+Its main responsibilty is to validate the map data as used by the package that
+takes the role of L<Map::Tube>. You can also unit test map functions as well.
 
 =head1 SYNOPSIS
 
@@ -167,10 +167,17 @@ v0.15 or above.
 
 sub ok_map_routes($$;$) {
     my ($object, $routes, $message) = @_;
-
-    $TEST->plan(tests => 1) unless $PLAN;
-    my ($response, $error) = _ok_map_routes($object, $routes);
-    $TEST->is_num($response, $TEST_BOOL, $message||$error);
+    my @errors = _ok_map_routes($object, $routes);
+    if (!@errors) {
+      $TEST->plan(tests => 1) unless $PLAN;
+      return $TEST->is_num($TEST_BOOL, $TEST_BOOL, $message);
+    }
+    $TEST->plan(tests => 0+@errors) unless $PLAN;
+    for (@errors) {
+      my ($g, $e, $d) = @$_;
+      my ($gs, $es) = map join("\n", @{$_->nodes}), $g, $e;
+      $TEST->is_eq($gs, $es, $message||$d)
+    }
 }
 
 #
@@ -289,24 +296,21 @@ sub _ok_map_functions {
 
 sub _ok_map_routes {
     my ($object, $routes) = @_;
-
     return 0 unless (defined $object && $object->does('Map::Tube'));
-
     eval { $object->get_map_data };
     ($@) and (carp('no map data found') and return 0);
-
+    my @failed;
     foreach (@$routes) {
         chomp;
         next if /^\#/;
         next if /^\s+$/;
-
         my ($description, $from, $to, $route) = split /\|/;
         my $got = $object->get_shortest_route($from, $to);
         my $expected = _expected_route($object, $route);
-        return (0, "Failed: $description") unless Compare($got, $expected);
+        next if Compare($got, $expected);
+        push @failed, [$got, $expected, $description];
     }
-
-    return 1;
+    return @failed;
 }
 
 sub _expected_route {
